==> qcware-2.2.1.tar.gz: qcware-2.2.1/tests/unit/test_solve_binary.py <==
import qcware
import pytest


@pytest.mark.parametrize("backend", (
    'qcware/cpu',
    'dwave/2000q',
    'dwave/advantage',
))
def test_solve_binary(backend):
    Q = {(0, 0): 1, (1, 1): 1, (0, 1): -2, (2, 2): -2, (3, 3): -4, (3, 2): -6}

    result = qcware.optimization.solve_binary(Q=Q, backend=backend)
    assert (result['solution'] == [0, 0, 1, 1]
            or result['solution'] == [1, 1, 1, 1])


@pytest.mark.parametrize("backend,nmeasurement",
                         [('qcware/cpu_simulator', None),
                          ('awsbraket/sv1', 1000)])
def test_solve_binary_qaoa(backend: str, nmeasurement: int):
    Q = {(0, 0): 1, (1, 1): 1, (0, 1): -2, (2, 2): -2, (3, 3): -4, (3, 2): -6}

    result = qcware.optimization.solve_binary(Q=Q,
                                              backend=backend,
                                              qaoa_optimizer='analytical',
                                              qaoa_nmeasurement=nmeasurement)
    assert (result['solution'] == [0, 0, 1, 1]
            or result['solution'] == [1, 1, 1, 1])


@pytest.mark.parametrize('optimizer',
                         ('COBYLA', 'bounded_Powell', 'analytical'))
def test_various_qaoa_optimizers(optimizer):
    Q = {(0, 0): 1, (1, 1): 1, (0, 1): -2, (2, 2): -2, (3, 3): -4, (3, 2): -6}
    result = qcware.optimization.solve_binary(Q=Q,
                                              backend='qcware/cpu_simulator',
                                              qaoa_optimizer=optimizer)
    assert (result['solution'] == [0, 0, 1, 1]
            or result['solution'] == [1, 1, 1, 1])


def test_analytical_angles_with_qaoa():
    Q = {(0, 0): 1, (1, 1): 1, (0, 1): -2, (2, 2): -2, (3, 3): -4, (3, 2): -5}

    exvals, angles, Z = qcware.optimization.find_optimal_qaoa_angles(
        Q, num_evals=100, num_min_vals=10)
    # print("EXVALS: ", exvals)
    # print("ANGLES: ", angles)

    result = qcware.optimization.solve_binary(Q=Q,
                                              backend='qcware/cpu_simulator',
                                              qaoa_beta=angles[1][0],
                                              qaoa_gamma=angles[1][1],
                                              qaoa_p_val=1)
    assert (result['solution'] == [0, 0, 1, 1]
            or result['solution'] == [1, 0, 1, 0]
            or result['solution'] == [1, 1, 1, 1])

==> qcware-4.0.0.tar.gz: qcware-4.0.0/tests/unit/test_solve_binary.py <==
import qcware
import pytest


@pytest.mark.parametrize("backend",
                         ('qcware/cpu', 'dwave/2000q', 'dwave/advantage')  # ,
#                           'awsbraket/dwave/2000q', 'awsbraket/dwave/advantage')
                         )
def test_solve_binary(backend):
    Q = {(0, 0): 1, (1, 1): 1, (0, 1): -2, (2, 2): -2, (3, 3): -4, (3, 2): -6}

    result = qcware.optimization.solve_binary(Q=Q, backend=backend)
    assert (result['solution'] == [0, 0, 1, 1]
            or result['solution'] == [1, 1, 1, 1])


@pytest.mark.parametrize("backend,nmeasurement",
                         [('qcware/cpu_simulator', None),
                          ('awsbraket/sv1', 1000)])
def test_solve_binary_qaoa(backend: str, nmeasurement: int):
    Q = {(0, 0): 1, (1, 1): 1, (0, 1): -2, (2, 2): -2, (3, 3): -4, (3, 2): -6}

    result = qcware.optimization.solve_binary(Q=Q,
                                              backend=backend,
                                              qaoa_optimizer='analytical',
                                              qaoa_nmeasurement=nmeasurement)
    assert (result['solution'] == [0, 0, 1, 1]
            or result['solution'] == [1, 1, 1, 1])


@pytest.mark.parametrize('optimizer',
                         ('COBYLA', 'bounded_Powell', 'analytical'))
def test_various_qaoa_optimizers(optimizer):
    Q = {(0, 0): 1, (1, 1): 1, (0, 1): -2, (2, 2): -2, (3, 3): -4, (3, 2): -6}
    result = qcware.optimization.solve_binary(Q=Q,
                                              backend='qcware/cpu_simulator',
                                              qaoa_optimizer=optimizer)
    assert (result['solution'] == [0, 0, 1, 1]
            or result['solution'] == [1, 1, 1, 1])


def test_analytical_angles_with_qaoa():
    Q = {(0, 0): 1, (1, 1): 1, (0, 1): -2, (2, 2): -2, (3, 3): -4, (3, 2): -5}

    exvals, angles, Z = qcware.optimization.find_optimal_qaoa_angles(
        Q, num_evals=100, num_min_vals=10)
    # print("EXVALS: ", exvals)
    # print("ANGLES: ", angles)

    result = qcware.optimization.solve_binary(Q=Q,
                                              backend='qcware/cpu_simulator',
                                              qaoa_beta=angles[1][0],
                                              qaoa_gamma=angles[1][1],
                                              qaoa_p_val=1)
    assert (result['solution'] == [0, 0, 1, 1]
            or result['solution'] == [1, 0, 1, 0]
            or result['solution'] == [1, 1, 1, 1])
